@@ -5,6 +5,7 @@ from zope.schema               import TextLine
 from zope.schema.fieldproperty import FieldProperty
 
 ALPHA = re.compile('^[a-zA-Z0-9_\-\.,\s]+$')
+ADDR  = re.compile('^[a-zA-Z0-9_\-\#\.,\s]+$')
 
 class IAddress(Interface):
     """Defines an interface for address types."""
@@ -12,7 +13,7 @@ class IAddress(Interface):
     firstname   = TextLine(title=u'First Name',   description=u'Given name',           required=False, constraint=ALPHA.match, max_length=50)
     lastname    = TextLine(title=u'Last Name',    description=u'Family name',          required=False, constraint=ALPHA.match, max_length=50)
     company     = TextLine(title=u'Company Name', description=u'Company name',         required=False, constraint=ALPHA.match, max_length=50)
-    address     = TextLine(title=u'Address',      description=u'Address',              required=False, constraint=ALPHA.match, max_length=60)
+    address     = TextLine(title=u'Address',      description=u'Address',              required=False, constraint=ADDR.match, max_length=60)
     city        = TextLine(title=u'City',         description=u'City of residence',    required=False, constraint=ALPHA.match, max_length=40)
     state       = TextLine(title=u'State',        description=u'State of residence',   required=False, constraint=ALPHA.match, max_length=40)
     country     = TextLine(title=u'Country',      description=u'Country of residence', required=False, constraint=ALPHA.match, max_length=60)
