@@ -1,7 +1,7 @@
 import datetime
 import re
 
-from paypy.schemas             import billing, shipping
+from paypy.schemas             import billing, shipping, transaction
 from paypy.schemas.payment     import IPayment
 from paypy.schemas.authnet     import IMerchantAuthentication
 from zope.interface            import Interface, implements
@@ -11,9 +11,13 @@ from zope.schema.fieldproperty import FieldProperty
 ALPHA      = re.compile('^[a-zA-Z0-9_\-.,\s]+$')
 CURRENCY   = re.compile('^[0-9]+.[0-9][0-9]$')
 
-class IAuthnetSubscription(Interface):
+# Super parent interfaces
+class IAuthnetSubscription(transaction.ITransaction):
     pass
+class SAuthnetSubscription(transaction.STransaction):
+    implements(IAuthnetSubscription)
 
+# Primary ARB interface object
 class IArb(Interface):
     """Represents an AIM interface."""
     
@@ -72,7 +76,7 @@ class IAuthnetSubscriptionWrite(IAuthnetSubscription):
     # Since payment can be either credit card or bank, we don't specify a schema type constraint, but we should - I may do this with a parent class in the future
     payment      = Object(title=u'Payment', description=u'Payment options', schema=IPayment, required=True)
 
-class SAuthnetSubscriptionWrite(object):
+class SAuthnetSubscriptionWrite(SAuthnetSubscription):
     implements(IAuthnetSubscriptionWrite)
     
     ref_id       = FieldProperty(IAuthnetSubscriptionWrite['ref_id'])
@@ -92,7 +96,7 @@ class IAuthnetSubscriptionRead(IAuthnetSubscription):
     id     = TextLine(title=u'Subscription ID', description=u'The subscription\'s ID.', max_length=13, required=True)
     ref_id = TextLine(title=u'Reference ID',    description=u'If included in the request, this value will be included in the response. This feature might be especially useful for multi- threaded applications.', max_length=20, required=False)
 
-class SAuthnetSubscriptionRead(object):
+class SAuthnetSubscriptionRead(SAuthnetSubscription):
     implements(IAuthnetSubscriptionRead)
     
     id     = FieldProperty(IAuthnetSubscriptionRead['id'])
